# Demod

## _Domestic Energy Demand Modelling Library_

Demod is a Python library for assembling bottom-up domestic
energy demand models.

## Documentation

Available at https://demod.readthedocs.io/en/latest/

## Installation

```sh
pip install demod
```

Source code: [GitHub Repository](https://github.com/epfl-herus/demod)

## Dependencies
* [numpy](https://numpy.org/)
* [pandas](https://pandas.pydata.org/)
* [scipy](https://www.scipy.org/)
* [openpyxl](https://openpyxl.readthedocs.io/en/stable/)
* [matplotlib](https://matplotlib.org/)

## Licence

[GPLv3](https://www.gnu.org/licenses/gpl-3.0.html)

## About

This repository is managed by
[HERUS lab](https://www.epfl.ch/labs/herus/) from
[EPFL : École Polytechnique Fédérale de Lausanne](https://www.epfl.ch/en/).

Please report bugs and ideas for improvement to
[our team](demod@groupes.epfl.ch) .
